// This Source Code Form is subject to the terms of the Mozilla Public
// License, v. 2.0. If a copy of the MPL was not distributed with this
// file, You can obtain one at http://mozilla.org/MPL/2.0/.

//! Primary beam code for the Murchison Widefield Array.

mod constants;
mod factorial;
pub mod fee;
mod legendre;
mod types;

#[cfg(feature = "python")]
mod python;

#[cfg(test)]
mod jones_test;
